@@ -21,6 +21,7 @@
 
 #include "kirigamiplugin.h"
 #include "enums.h"
+#include "desktopicon.h"
 
 #include <QQmlEngine>
 #include <QQmlContext>
@@ -43,10 +44,6 @@ QString KirigamiPlugin::componentPath(const QString &fileName) const
 
 void KirigamiPlugin::registerTypes(const char *uri)
 {
-#ifdef KIRIGAMI_BUILD_TYPE_STATIC
-    Q_INIT_RESOURCE(kirigami);
-#endif
-
     Q_ASSERT(uri == QLatin1String("org.kde.kirigami"));
     const QString style = QString::fromLatin1(qgetenv("QT_QUICK_CONTROLS_STYLE"));
 
@@ -82,7 +79,18 @@ void KirigamiPlugin::registerTypes(const char *uri)
     qmlRegisterType(componentPath(QStringLiteral("ContextDrawer.qml")), uri, 1, 0, "ContextDrawer");
     qmlRegisterType(componentPath(QStringLiteral("GlobalDrawer.qml")), uri, 1, 0, "GlobalDrawer");
     qmlRegisterType(componentPath(QStringLiteral("Heading.qml")), uri, 1, 0, "Heading");
+
+    //The icon is "special: we have to use a wrapper class to QIcon on desktops
+#if !defined(Q_OS_ANDROID) && !defined(Q_OS_IOS)
+    if (m_stylesFallbackChain.first() == QStringLiteral("Desktop")) {
+        qmlRegisterType<DesktopIcon>(uri, 1, 0, "Icon");
+    } else {
+        qmlRegisterType(componentPath(QStringLiteral("Icon.qml")), uri, 1, 0, "Icon");
+    }
+#else
     qmlRegisterType(componentPath(QStringLiteral("Icon.qml")), uri, 1, 0, "Icon");
+#endif
+
     qmlRegisterType(componentPath(QStringLiteral("Label.qml")), uri, 1, 0, "Label");
     qmlRegisterType(componentPath(QStringLiteral("OverlaySheet.qml")), uri, 1, 0, "OverlaySheet");
     qmlRegisterType(componentPath(QStringLiteral("Page.qml")), uri, 1, 0, "Page");
